@@ -5,23 +5,22 @@
 
 #define DEBUGGER 1
 
-#if __WIN32__ || __CYGWIN__ || MINGW32
+#if __WINDOWS__ || __CYGWIN__ || MINGW32 || _MSC_VER || CUTTER
 #define R2_PREFIX "."
 #define R2_LIBDIR "./lib"
 #define R2_INCDIR "./include/libr"
 #define R2_DATDIR "./share"
 #else
-#define R2_PREFIX "/usr/local"
-#define R2_LIBDIR "/usr/local/lib"
-#define R2_INCDIR "/usr/local/include/libr"
-#define R2_DATDIR "/usr/local/share"
+#define R2_PREFIX "/usr/pkg"
+#define R2_LIBDIR "/usr/pkg/lib"
+#define R2_INCDIR "/usr/pkg/include/libr"
+#define R2_DATDIR "/usr/pkg/share"
 #endif
 
-#define R2_VERSION "0.10.6"
-#define HAVE_LIB_MAGIC 0
-#define USE_LIB_MAGIC 0
+#define HAVE_LIB_MAGIC 1
+#define USE_LIB_MAGIC 1
 #ifndef HAVE_LIB_SSL
-#define HAVE_LIB_SSL 1
+#define HAVE_LIB_SSL 0
 #endif
 
 #define HAVE_FORK 1
@@ -30,4 +29,10 @@
 
 #define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
 
+#if __APPLE__ && __POWERPC__
+#define HAVE_JEMALLOC 0
+#else
+#define HAVE_JEMALLOC 1
+#endif
+
 #endif
